<?php
/**
 * Popular Posts section
 *
 * This is the template for the content of popular_posts section
 *
 * @package Theme Palace
 * @subpackage Businesszen Dairy
 * @since Businesszen Dairy 1.0.0
 */
if ( ! function_exists( 'businesszen_dairy_add_popular_posts_section' ) ) :
    /**
    * Add popular_posts section
    *
    *@since Businesszen Dairy 1.0.0
    */
    function businesszen_dairy_add_popular_posts_section() {
        
        // Check if popular_posts is enabled on frontpage
        if ( get_theme_mod( 'popular_posts_section_enable' ) == false ) {
            return false;
        }

        // Get popular_posts section details
        $section_details = array();
        $section_details = apply_filters( 'businesszen_dairy_filter_popular_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_posts section now.
        businesszen_dairy_render_popular_posts_section( $section_details );
    }

endif;

if ( ! function_exists( 'businesszen_dairy_get_popular_posts_section_details' ) ) :
    /**
    * popular_posts section details.
    *
    * @since Businesszen Dairy 1.0.0
    * @param array $input popular_posts section details.
    */
    function businesszen_dairy_get_popular_posts_section_details( $input ) {
        $content  = array();
        $post_ids = array();
        for ( $i = 1; $i <= 4; $i++ ) {
            if ( ! empty( get_theme_mod( 'popular_posts_content_post_'.$i ) ) )
                $post_ids[] = get_theme_mod( 'popular_posts_content_post_'.$i );
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( 4 ),
            'orderby'           => 'post__in',
        );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = businesszen_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_posts section content details.
add_filter( 'businesszen_dairy_filter_popular_posts_section_details', 'businesszen_dairy_get_popular_posts_section_details' );


if ( ! function_exists( 'businesszen_dairy_render_popular_posts_section' ) ) :
  /**
   * Start popular_posts section
   *
   * @return string popular_posts content
   * @since Businesszen Dairy 1.0.0
   *
   */
   function businesszen_dairy_render_popular_posts_section( $content_details = array() ) {

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="inner-content-wrapper popular_posts_section" class="wrapper page-section">
            <div id="primary" class="content-area">
                <main id="main" class="site-main" role="main">
                    <div id="businesszen_popular_posts_section" class="archive-blog-wrapper col-2 clear">
                        <?php foreach ($content_details as $content ): ?>
                            <article>
                                <div class="post-wrapper">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="blog"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span>

                                            <?php businesszen_posted_on( $content['id'] ) ; ?>
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .post-wrapper -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- #businesszen_popular_posts_section -->
                </main><!-- #main -->
            </div><!-- #primary -->

            <?php if(is_active_sidebar('popular-posts-sidebar')): ?>

                <aside id="secondary" class="widget-area" role="complementary">
                    <?php dynamic_sidebar( 'popular-posts-sidebar' ); ?>
                </aside><!-- #secondary -->

            <?php endif; ?>
        </div><!-- #inner-content-wrapper-->
              
    <?php
    }
endif;